Plotting Data
=============

.. contents::

.. automodule:: fretbursts.burst_plot


Timetrace and ratetrace plots
-----------------------------

.. autofunction:: timetrace

.. autofunction:: timetrace_single

.. autofunction:: ratetrace

.. autofunction:: ratetrace_single

.. autofunction:: timetrace_bg

.. autofunction:: timetrace_b_rate


1D Histograms
-------------

Bursts: ratiometric quantities
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: hist_fret

.. autofunction:: hist_S

.. autofunction:: hist_burst_data


Bursts: tail distributions
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: hist_size

.. autofunction:: hist_size_all

.. autofunction:: hist_width

.. autofunction:: hist_brightness

.. autofunction:: hist_sbr

.. autofunction:: hist_burst_phrate


Others
~~~~~~

.. autofunction:: hist_interphoton_single

.. autofunction:: hist_interphoton

.. autofunction:: hist_bg_single

.. autofunction:: hist_bg

.. autofunction:: hist_burst_delays

.. autofunction:: hist_asymmetry


ALEX plots
----------

.. autofunction:: alex_jointplot

.. autofunction:: hist2d_alex

.. autofunction:: hexbin_alex

.. autofunction:: plot_ES_selection

.. autofunction:: plot_alternation_hist

.. autofunction:: plot_alternation_hist_nsalex


Scatter plots
-------------

.. autofunction:: scatter_width_size

.. autofunction:: scatter_da

.. autofunction:: scatter_rate_da

.. autofunction:: scatter_fret_size

.. autofunction:: scatter_fret_nd_na

.. autofunction:: scatter_fret_width

.. autofunction:: scatter_naa_nt

.. autofunction:: scatter_alex
